pub enum LockError {
AlreadyClaimed {
item: String,
owner: String,
requester: String,
},
NotClaimed {
item: String,
},
NotOwner {
item: String,
owner: String,
requester: String,
},
UnknownItem {
item: String,
},
}Expand description
Errors from lock operations.
Variants
AlreadyClaimed
The item is already claimed by a different agent.
NotClaimed
The item is not claimed (cannot unlock).
NotOwner
The item is claimed by a different agent (cannot unlock).
UnknownItem
The requested item does not exist in the spec.